'use strict';

var ManterObraController = angular.module('ManterObraController', []);

ManterObraController.controller('ManterObraCtrl', ['$scope', '$filter', '$rootScope', 'Construcao', 'Endereco', 'CacheApp',
  ($scope, $filter, $rootScope, Construcao, Endereco, CacheApp) => {

    $scope.$on('salvarObra', (event, args) => {
        $scope.setConstrucao()
    })

    $scope.setConstrucao = () => {
        if ($scope.construcao.Tipo == 3) {
            if ($scope.formObra.txtTitulo.$error.required)
                return;
        }
        else
            if ($scope.formObra.txtTitulo.$error.required ||
                $scope.formObra.txtContato.$error.required ||
                $scope.formObra.txtTelefone.$error.required) {
                return;
            }

        $scope.construcao.Id = $scope.construcao.Id ? $scope.construcao.Id : 0;

        if ($scope.construcao.BDITipo == 0) {
            $scope.construcao.BDIMaterial = null;
            $scope.construcao.BDIEquipamento = null;
            $scope.construcao.BDIMaoObra = null;
            $scope.construcao.BDIServico = null;
            $scope.construcao.BDITaxa = null;
        }
        else {
            $scope.construcao.BDI = null;
        }

        var dataIni = $scope.construcao.DataInicio;
        var dataFim = $scope.construcao.DataFim;
        dataIni.setHours(3,5,1);
        dataFim.setHours(3,5,1);
        $scope.construcao.DataInicio = dataIni;
        $scope.construcao.DataFim = dataFim;

        var sessao = CacheApp.getSessao()
        $scope.construcao.IdClienteAdmin = sessao.ContaAdmin ? sessao.IdClienteAdmin : undefined
        Construcao.setConstrucao($scope.construcao,
            (data) => {
                $scope.construcao.Id = data.Instance[0].IdConstrucao;
                CacheApp.setConstrucao($scope.construcao);
                $rootScope.$broadcast('refreshComboObra', {});
            });

    }

    $scope.getListaConfiguracao = () => {
        Construcao.getListaConfiguracao(
            (data) => {
                $scope.listaConfiguracao = data.Instance;
            });
    }

    $scope.selecionaTipo = function() {
        $scope.construcao.Tipo = $scope.tipoSelecionado.Id;
        $scope.construcao.TipoNome = $scope.tipoSelecionado.Nome;
    }

    $scope.selecionaBDI = function(bdi) {
        $scope.construcao.BDITipo = bdi;
    }

    $scope.getTipoObra = (callBack) => {
        Construcao.getTipoObra(
            (data) => {
                if ($scope.sessao.Acessos.indexOf('GET_FINANCEIRO') < 0)
                    $scope.listaTipo = data.Instance.filter(t => t.Id != 3)
                else
                    $scope.listaTipo = data.Instance

                callBack();
            });
    }

    $scope.getListaEstado = () => {
        var params = {
            IdPais: $scope.construcao && $scope.construcao.IdConfiguracao ? $scope.construcao.IdConfiguracao : 1
        }
        Endereco.getListaEstado(params,
            (data) => {
                $scope.listaEstado = data.Instance;
                if ($scope.construcao.Id != 0) {
                    var estado = $scope.listaEstado.filter(e => e.Nome == $scope.construcao.Estado || e.UF == $scope.construcao.Estado);
                    if (estado && estado.length > 0) {
                        $scope.getListaCidade(estado[0].Id);
                        $scope.construcao.IdEstado = estado[0].Id.toString();
                    }
                    else
                        $scope.construcao.IdEstado = '';
                }
            }
        );
    }

    $scope.getListaCidade = (IdEstado) => {
        var params = {
            IdEstado: IdEstado
        }
        $scope.construcao.Estado = $scope.listaEstado.filter(e => e.Id == IdEstado)[0].UF;
        Endereco.getListaCidade(params,
            (data) => {
                $scope.listaCidade = data.Instance;
                if ($scope.construcao.Id != 0) {
                    var cidade = $scope.listaCidade.filter(c => c.Nome == $scope.construcao.Cidade);
                    $scope.construcao.IdCidade = cidade && cidade.length > 0 ? cidade[0].Id.toString() : '';
                }
            });
    }
    
    $scope.setCidadeSelecionada = (IdCidade) => {
        $scope.construcao.Cidade = $scope.listaCidade.filter(c => c.Id == IdCidade)[0].Nome;
    }

    $scope.getEnderecoCEP = (obra) => {
        if (obra.CEP.length != 8) return;
        Endereco.getEnderecoCEP(obra.CEP,
            (data) => {
                obra.Endereco = data.logradouro;
                obra.Bairro = data.bairro;
                $scope.listaEstado.forEach(
                    e => {
                        if (e.UF == data.uf) {
                            obra.IdEstado = e.Id.toString();
                            obra.Estado = e.UF;
                        }
                    }
                );
                var params = {
                    IdEstado: obra.IdEstado
                }
                Endereco.getListaCidade(params,
                    (result) => {
                        $scope.listaCidade = result.Instance;
                        $scope.listaCidade.forEach(
                            c => {
                                if (c.Nome == data.localidade) {
                                    obra.IdCidade = c.Id.toString();
                                    obra.Cidade = c.Nome;
                                }
                            }
                        );
                    }
                );
            }
        );
    }

    $scope.LoadPage = () => {
        $scope.idioma = CacheApp.getIdioma();
        $scope.sessao = CacheApp.getSessao();

        $scope.construcao.DataInicio = CacheApp.getData($scope.construcao.DataInicio ? $filter("date")($scope.construcao.DataInicio, 'yyyy-MM-ddT00:00:00Z') : $filter("date")(Date.now(), 'yyyy-MM-ddT00:00:00Z'));
        $scope.construcao.DataFim = CacheApp.getData($scope.construcao.DataFim ? $filter("date")($scope.construcao.DataFim, 'yyyy-MM-ddT00:00:00Z') : $filter("date")(Date.now(), 'yyyy-MM-ddT00:00:00Z'));
        $scope.construcao.BDITipo = $scope.construcao.Id ? 1 : ($scope.construcao.BDI ? 0 : 1);

        $scope.getListaConfiguracao();
        $scope.getListaEstado();

        $scope.getTipoObra(( () => {
            for (var i in $scope.listaTipo) {
                if ($scope.construcao.Tipo == $scope.listaTipo[i].Id)
                    $scope.tipoSelecionado = $scope.listaTipo[i];
            }    
        }));

        $scope.listaBDI = [
            {Id: 0, Descricao: 'BDI Único'},
            {Id: 1, Descricao: 'BDI Diferenciado'}
        ];

        $scope.construcao.BDITipo = $scope.construcao.Novo ? 0 : ($scope.construcao.BDI ? 0 : $scope.construcao.BDITipo);
        $scope.bdiSelecionado = $scope.listaBDI[$scope.construcao.Novo ? 0 : $scope.construcao.BDITipo];
    }

    $scope.LoadPage()
  }]);
